package org.eco.als.service;

import org.eco.als.domain.SafeRule;
import org.eco.als.domain.bo.SafeRuleBo;
import org.eco.als.domain.vo.SafeRuleVo;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.common.core.core.page.PageResult;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
 * 保障规则Service接口
 *
 * @author wgk
 * @date 2024-07-24
 */
public interface ISafeRuleService extends IBaseService<SafeRule> {
    /**
     * 查询保障规则
     *
     * @param id 保障规则主键
     * @return 保障规则
     */
    SafeRuleVo selectById(Long id);

    /**
     * 查询保障规则列表
     *
     * @param safeRuleBo 保障规则Bo
     * @return 保障规则集合
     */
    List<SafeRuleVo> selectList(SafeRuleBo safeRuleBo);

    /**
     * 分页查询保障规则列表
     *
     * @param safeRuleBo 保障规则Bo
     * @return 分页保障规则集合
     */
    PageResult<SafeRuleVo> selectPage(SafeRuleBo safeRuleBo);

    /**
     * 新增保障规则
     *
     * @param safeRuleBo 保障规则Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(SafeRuleBo safeRuleBo);

    /**
     * 新增保障规则，前台提供主键值，一般用于导入的场合
     *
     * @param safeRuleBo 保障规则Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(SafeRuleBo safeRuleBo);

    /**
     * 修改保障规则
     *
     * @param safeRuleBo 保障规则Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(SafeRuleBo safeRuleBo);

    /**
     * 批量删除保障规则
     *
     * @param ids 需要删除的保障规则主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * 异步导入
     *
     * @param file          导入的文件
     * @param updateSupport 是否覆盖
     * @param user          用户上下文信息
     */
    @Async
    void asyncImportData(MultipartFile file, boolean updateSupport, LoginUser user);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<SafeRuleVo> listVo, String sheetName, LoginUser user);

}
