package org.eco.als.service;

import org.eco.als.domain.SafeRuleSub;
import org.eco.als.domain.bo.SafeRuleSubBo;
import org.eco.als.domain.vo.SafeRuleSubVo;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.common.core.core.page.PageResult;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
 * 保障规则子Service接口
 *
 * @author wgk
 * @date 2024-07-24
 */
public interface ISafeRuleSubService extends IBaseService<SafeRuleSub> {
    /**
     * 查询保障规则子
     *
     * @param id 保障规则子主键
     * @return 保障规则子
     */
    SafeRuleSubVo selectById(Long id);

    /**
     * 查询保障规则子列表
     *
     * @param safeRuleSubBo 保障规则子Bo
     * @return 保障规则子集合
     */
    List<SafeRuleSubVo> selectList(SafeRuleSubBo safeRuleSubBo);

    /**
     * 分页查询保障规则子列表
     *
     * @param safeRuleSubBo 保障规则子Bo
     * @return 分页保障规则子集合
     */
    PageResult<SafeRuleSubVo> selectPage(SafeRuleSubBo safeRuleSubBo);

    /**
     * 新增保障规则子
     *
     * @param safeRuleSubBo 保障规则子Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(SafeRuleSubBo safeRuleSubBo);

    /**
     * 新增保障规则子，前台提供主键值，一般用于导入的场合
     *
     * @param safeRuleSubBo 保障规则子Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(SafeRuleSubBo safeRuleSubBo);

    /**
     * 修改保障规则子
     *
     * @param safeRuleSubBo 保障规则子Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(SafeRuleSubBo safeRuleSubBo);

    /**
     * 批量删除保障规则子
     *
     * @param ids 需要删除的保障规则子主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * 异步导入
     *
     * @param file          导入的文件
     * @param updateSupport 是否覆盖
     * @param user          用户上下文信息
     */
    @Async
    void asyncImportData(MultipartFile file, boolean updateSupport, LoginUser user);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<SafeRuleSubVo> listVo, String sheetName, LoginUser user);

}
