CREATE TABLE "als"."als_air_configuration_t"
(
    "id" BIGINT NOT NULL,
    "parent_id" BIGINT,
    "parent_name" VARCHAR2(255),
    "ancestors" VARCHAR(760) DEFAULT '',
    "aircraft_type" VARCHAR2(255),
    "con_code" VARCHAR2(255),
    "name" VARCHAR2(255),
    "specs_model" VARCHAR2(255),
    "drawing_number" VARCHAR2(255),
    "supplier" VARCHAR2(255),
    "remarks" VARCHAR2(900),
    "tenant_id" VARCHAR2(8188),
    "order_num" INT DEFAULT 0,
    "del_flag" BIT DEFAULT 0,
    "version" INTEGER,
    "create_by" VARCHAR2(8188),
    "create_time" TIMESTAMP(6),
    "update_by" VARCHAR2(8188),
    "update_time" TIMESTAMP(6),
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_air_configuration_t" IS '飞机构型';

COMMENT ON COLUMN "als"."als_air_configuration_t"."aircraft_type" IS '机型';

COMMENT ON COLUMN "als"."als_air_configuration_t"."con_code" IS '构型编码';

COMMENT ON COLUMN "als"."als_air_configuration_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_air_configuration_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_air_configuration_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_air_configuration_t"."drawing_number" IS '图号';

COMMENT ON COLUMN "als"."als_air_configuration_t"."id" IS '唯一ID';

COMMENT ON COLUMN "als"."als_air_configuration_t"."name" IS '产品名称';

COMMENT ON COLUMN "als"."als_air_configuration_t"."parent_id" IS '父Id';

COMMENT ON COLUMN "als"."als_air_configuration_t"."parent_name" IS '父名称';

COMMENT ON COLUMN "als"."als_air_configuration_t"."remarks" IS '描述';

COMMENT ON COLUMN "als"."als_air_configuration_t"."specs_model" IS '规格型号';

COMMENT ON COLUMN "als"."als_air_configuration_t"."supplier" IS '供应商';

COMMENT ON COLUMN "als"."als_air_configuration_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_air_configuration_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_air_configuration_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_air_configuration_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_air_install_t"
(
    "id" BIGINT NOT NULL,
    "config_id" VARCHAR2(255),
    "devices_encode" VARCHAR2(255),
    "devices_code" VARCHAR2(255),
    "devices_name" VARCHAR2(255),
    "specs_model" VARCHAR2(255),
    "drawing_number" VARCHAR2(255),
    "category" VARCHAR2(255),
    "quantity" VARCHAR2(255),
    "install_time" VARCHAR2(255),
    "software_version" VARCHAR2(255),
    "repairable" CHAR(1),
    "complete_set" CHAR(1),
    "service_life" CHAR(1),
    "remarks" VARCHAR2(900),
    "tenant_id" BIGINT,
    "del_flag" BIT DEFAULT 0,
    "version" INTEGER,
    "create_by" VARCHAR2(8188),
    "create_time" TIMESTAMP(6),
    "update_by" VARCHAR2(8188),
    "update_time" TIMESTAMP(6),
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_air_install_t" IS '装机信息';

COMMENT ON COLUMN "als"."als_air_install_t"."category" IS '所属分类';

COMMENT ON COLUMN "als"."als_air_install_t"."complete_set" IS '是否成套';

COMMENT ON COLUMN "als"."als_air_install_t"."config_id" IS '构型Id';

COMMENT ON COLUMN "als"."als_air_install_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_air_install_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_air_install_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_air_install_t"."devices_code" IS '器材代码';

COMMENT ON COLUMN "als"."als_air_install_t"."devices_encode" IS '器材编码';

COMMENT ON COLUMN "als"."als_air_install_t"."devices_name" IS '器材名称';

COMMENT ON COLUMN "als"."als_air_install_t"."drawing_number" IS '图号';

COMMENT ON COLUMN "als"."als_air_install_t"."id" IS '唯一ID';

COMMENT ON COLUMN "als"."als_air_install_t"."install_time" IS '装机时间';

COMMENT ON COLUMN "als"."als_air_install_t"."quantity" IS '装机数量';

COMMENT ON COLUMN "als"."als_air_install_t"."remarks" IS '备注';

COMMENT ON COLUMN "als"."als_air_install_t"."repairable" IS '是否可修';

COMMENT ON COLUMN "als"."als_air_install_t"."service_life" IS '是否有寿';

COMMENT ON COLUMN "als"."als_air_install_t"."software_version" IS '软件版本';

COMMENT ON COLUMN "als"."als_air_install_t"."specs_model" IS '规格型号';

COMMENT ON COLUMN "als"."als_air_install_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_air_install_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_air_install_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_air_install_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_aircraft_t"
(
    "id" BIGINT NOT NULL,
    "parent_id" VARCHAR2(255),
    "parent_name" VARCHAR2(255),
    "name" VARCHAR2(255),
    "ancestors" VARCHAR2(800),
    "order_num" INTEGER DEFAULT 0,
    "tenant_id" BIGINT,
    "version" INTEGER,
    "del_flag" BIT DEFAULT 0,
    "create_by" BIGINT,
    "create_time" TIMESTAMP(6),
    "update_by" BIGINT,
    "update_time" TIMESTAMP(6),
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_aircraft_t" IS '机型机号';

COMMENT ON COLUMN "als"."als_aircraft_t"."ancestors" IS '祖级列表';

COMMENT ON COLUMN "als"."als_aircraft_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_aircraft_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_aircraft_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_aircraft_t"."id" IS '编号';

COMMENT ON COLUMN "als"."als_aircraft_t"."name" IS '机型/机号';

COMMENT ON COLUMN "als"."als_aircraft_t"."order_num" IS '显示顺序';

COMMENT ON COLUMN "als"."als_aircraft_t"."parent_id" IS '机型Id';

COMMENT ON COLUMN "als"."als_aircraft_t"."parent_name" IS '机型Name';

COMMENT ON COLUMN "als"."als_aircraft_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_aircraft_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_aircraft_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_aircraft_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_carry_checklist_t"
(
    "id" BIGINT NOT NULL,
    "aircraft_model" VARCHAR2(255),
    "aircraft_id" CHAR(255),
    "name" VARCHAR2(255),
    "model" VARCHAR2(255),
    "factory" VARCHAR2(255),
    "quantity" INTEGER,
    "remark" VARCHAR2(900),
    "status" CHAR(1) DEFAULT 1,
    "tenant_id" BIGINT,
    "version" INTEGER,
    "del_flag" BIT DEFAULT 0,
    "create_by" BIGINT,
    "create_time" TIMESTAMP(6),
    "update_by" BIGINT,
    "update_time" TIMESTAMP(6),
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_carry_checklist_t" IS '任务携行';

COMMENT ON COLUMN "als"."als_carry_checklist_t"."aircraft_id" IS '机号';

COMMENT ON COLUMN "als"."als_carry_checklist_t"."aircraft_model" IS '机型';

COMMENT ON COLUMN "als"."als_carry_checklist_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_carry_checklist_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_carry_checklist_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_carry_checklist_t"."factory" IS '厂家名称';

COMMENT ON COLUMN "als"."als_carry_checklist_t"."id" IS '编号';

COMMENT ON COLUMN "als"."als_carry_checklist_t"."model" IS '型号';

COMMENT ON COLUMN "als"."als_carry_checklist_t"."name" IS '成品名称';

COMMENT ON COLUMN "als"."als_carry_checklist_t"."quantity" IS '需求数量';

COMMENT ON COLUMN "als"."als_carry_checklist_t"."remark" IS '备注';

COMMENT ON COLUMN "als"."als_carry_checklist_t"."status" IS '状态（1正常）';

COMMENT ON COLUMN "als"."als_carry_checklist_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_carry_checklist_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_carry_checklist_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_carry_checklist_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_data_analysis_t"
(
    "id" BIGINT NOT NULL,
    "oss_id" BIGINT,
    "source" CHAR(1),
    "sortie_no" VARCHAR2(255),
    "aircraft_id" CHAR(255),
    "flight_date" DATE,
    "status" CHAR(1) DEFAULT 1,
    "tenant_id" BIGINT,
    "version" INTEGER,
    "del_flag" BIT DEFAULT 0,
    "create_by" BIGINT,
    "create_time" TIMESTAMP(6),
    "update_by" BIGINT,
    "update_time" TIMESTAMP(6),
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_data_analysis_t" IS '数据解析';

COMMENT ON COLUMN "als"."als_data_analysis_t"."aircraft_id" IS '机号';

COMMENT ON COLUMN "als"."als_data_analysis_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_data_analysis_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_data_analysis_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_data_analysis_t"."flight_date" IS '飞行日期';

COMMENT ON COLUMN "als"."als_data_analysis_t"."id" IS '数据编号';

COMMENT ON COLUMN "als"."als_data_analysis_t"."oss_id" IS '文件编号';

COMMENT ON COLUMN "als"."als_data_analysis_t"."sortie_no" IS '架次号';

COMMENT ON COLUMN "als"."als_data_analysis_t"."source" IS '数据源';

COMMENT ON COLUMN "als"."als_data_analysis_t"."status" IS '状态（1正常）';

COMMENT ON COLUMN "als"."als_data_analysis_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_data_analysis_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_data_analysis_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_data_analysis_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_data_import_t"
(
    "id" BIGINT NOT NULL,
    "oss_id" BIGINT,
    "source" CHAR(1),
    "sortie_no" VARCHAR2(255),
    "aircraft_id" CHAR(255),
    "flight_date" DATE,
    "status" CHAR(1) DEFAULT 1,
    "tenant_id" BIGINT,
    "version" INTEGER,
    "del_flag" BIT DEFAULT 0,
    "create_by" BIGINT,
    "create_time" TIMESTAMP(6),
    "update_by" BIGINT,
    "update_time" TIMESTAMP(6),
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_data_import_t" IS '数据导入信息';

COMMENT ON COLUMN "als"."als_data_import_t"."aircraft_id" IS '机号';

COMMENT ON COLUMN "als"."als_data_import_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_data_import_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_data_import_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_data_import_t"."flight_date" IS '飞行日期';

COMMENT ON COLUMN "als"."als_data_import_t"."id" IS '唯一编号';

COMMENT ON COLUMN "als"."als_data_import_t"."oss_id" IS '文件编号';

COMMENT ON COLUMN "als"."als_data_import_t"."sortie_no" IS '架次号';

COMMENT ON COLUMN "als"."als_data_import_t"."source" IS '数据源';

COMMENT ON COLUMN "als"."als_data_import_t"."status" IS '状态（1正常）';

COMMENT ON COLUMN "als"."als_data_import_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_data_import_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_data_import_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_data_import_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_false_alarm_result_t"
(
    "id" BIGINT NOT NULL,
    "false_alarm_id" BIGINT,
    "sortie_no" VARCHAR2(255),
    "aircraft_id" CHAR(255),
    "code" VARCHAR2(255),
    "name" VARCHAR2(255),
    "describe" VARCHAR2(900),
    "status" CHAR(1) DEFAULT 1,
    "tenant_id" BIGINT,
    "version" INTEGER,
    "del_flag" BIT DEFAULT 0,
    "create_by" BIGINT,
    "create_time" TIMESTAMP(6),
    "update_by" BIGINT,
    "update_time" TIMESTAMP(6),
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_false_alarm_result_t" IS '虚警抑制结果';

COMMENT ON COLUMN "als"."als_false_alarm_result_t"."aircraft_id" IS '机号';

COMMENT ON COLUMN "als"."als_false_alarm_result_t"."code" IS '警告代码';

COMMENT ON COLUMN "als"."als_false_alarm_result_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_false_alarm_result_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_false_alarm_result_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_false_alarm_result_t"."describe" IS '警告描述';

COMMENT ON COLUMN "als"."als_false_alarm_result_t"."false_alarm_id" IS '虚警抑制Id';

COMMENT ON COLUMN "als"."als_false_alarm_result_t"."id" IS '编号';

COMMENT ON COLUMN "als"."als_false_alarm_result_t"."name" IS '警告名称';

COMMENT ON COLUMN "als"."als_false_alarm_result_t"."sortie_no" IS '架次号';

COMMENT ON COLUMN "als"."als_false_alarm_result_t"."status" IS '状态（1是）';

COMMENT ON COLUMN "als"."als_false_alarm_result_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_false_alarm_result_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_false_alarm_result_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_false_alarm_result_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_false_alarm_t"
(
    "id" BIGINT NOT NULL,
    "sortie_no" VARCHAR2(255),
    "aircraft_id" CHAR(255),
    "model_type" CHAR(1),
    "param" VARCHAR2(2000),
    "column_data" VARCHAR2(2000),
    "oss_id" BIGINT,
    "status" CHAR(1) DEFAULT 1,
    "tenant_id" BIGINT,
    "version" INTEGER,
    "del_flag" BIT DEFAULT 0,
    "create_by" BIGINT,
    "create_time" TIMESTAMP(6),
    "update_by" BIGINT,
    "update_time" TIMESTAMP(6),
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_false_alarm_t" IS '虚警抑制';

COMMENT ON COLUMN "als"."als_false_alarm_t"."aircraft_id" IS '机号';

COMMENT ON COLUMN "als"."als_false_alarm_t"."column_data" IS '数据列';

COMMENT ON COLUMN "als"."als_false_alarm_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_false_alarm_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_false_alarm_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_false_alarm_t"."id" IS '编号';

COMMENT ON COLUMN "als"."als_false_alarm_t"."model_type" IS '模型类型';

COMMENT ON COLUMN "als"."als_false_alarm_t"."oss_id" IS '文件Id';

COMMENT ON COLUMN "als"."als_false_alarm_t"."param" IS '参数';

COMMENT ON COLUMN "als"."als_false_alarm_t"."sortie_no" IS '架次号';

COMMENT ON COLUMN "als"."als_false_alarm_t"."status" IS '状态（1正常）';

COMMENT ON COLUMN "als"."als_false_alarm_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_false_alarm_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_false_alarm_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_false_alarm_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_fault_case_t"
(
    "id" BIGINT NOT NULL,
    "aircraft_code" VARCHAR2(255),
    "aircraft_type" VARCHAR2(255),
    "fault_code" VARCHAR2(255),
    "fault_name" VARCHAR2(255),
    "oss_id" VARCHAR2(255),
    "fault_date" VARCHAR2(255),
    "system_item" VARCHAR2(255),
    "specialty" VARCHAR2(255),
    "LOCATION" VARCHAR2(255),
    "LEVEL" VARCHAR2(255),
    "symptoms" VARCHAR2(255),
    "method_rectification" VARCHAR2(255),
    "fault_cause_type" VARCHAR2(255),
    "fault_cause" VARCHAR2(255),
    "remarks" VARCHAR2(900),
    "tenant_id" BIGINT,
    "version" INTEGER,
    "del_flag" BIT DEFAULT 0,
    "create_by" BIGINT,
    "create_time" TIMESTAMP(6),
    "update_by" BIGINT,
    "update_time" TIMESTAMP(6),
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_fault_case_t" IS '故障案例';

COMMENT ON COLUMN "als"."als_fault_case_t"."aircraft_code" IS '飞机编号';

COMMENT ON COLUMN "als"."als_fault_case_t"."aircraft_type" IS '机型';

COMMENT ON COLUMN "als"."als_fault_case_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_fault_case_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_fault_case_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_fault_case_t"."fault_cause" IS '故障原因';

COMMENT ON COLUMN "als"."als_fault_case_t"."fault_cause_type" IS '故障原因分类';

COMMENT ON COLUMN "als"."als_fault_case_t"."fault_code" IS '故障代码';

COMMENT ON COLUMN "als"."als_fault_case_t"."fault_date" IS '日期';

COMMENT ON COLUMN "als"."als_fault_case_t"."fault_name" IS '故障名称';

COMMENT ON COLUMN "als"."als_fault_case_t"."id" IS '编号';

COMMENT ON COLUMN "als"."als_fault_case_t"."LEVEL" IS '故障性质';

COMMENT ON COLUMN "als"."als_fault_case_t"."LOCATION" IS '故障部位';

COMMENT ON COLUMN "als"."als_fault_case_t"."method_rectification" IS '排除方法';

COMMENT ON COLUMN "als"."als_fault_case_t"."oss_id" IS '故障文件';

COMMENT ON COLUMN "als"."als_fault_case_t"."remarks" IS '备注';

COMMENT ON COLUMN "als"."als_fault_case_t"."specialty" IS '专业';

COMMENT ON COLUMN "als"."als_fault_case_t"."symptoms" IS '故障现象';

COMMENT ON COLUMN "als"."als_fault_case_t"."system_item" IS '所属系统';

COMMENT ON COLUMN "als"."als_fault_case_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_fault_case_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_fault_case_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_fault_case_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_fault_consumable_t"
(
    "id" BIGINT NOT NULL,
    "consumable_name" VARCHAR2(255),
    "quantity" INTEGER,
    "purpose" VARCHAR2(255),
    "remarks" VARCHAR2(900),
    "tenant_id" BIGINT,
    "version" INTEGER,
    "del_flag" BIT DEFAULT 0,
    "create_by" BIGINT,
    "create_time" TIMESTAMP(6),
    "update_by" BIGINT,
    "update_time" TIMESTAMP(6),
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_fault_consumable_t" IS '故障所需耗材';

COMMENT ON COLUMN "als"."als_fault_consumable_t"."consumable_name" IS '耗材名称';

COMMENT ON COLUMN "als"."als_fault_consumable_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_fault_consumable_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_fault_consumable_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_fault_consumable_t"."id" IS '编号';

COMMENT ON COLUMN "als"."als_fault_consumable_t"."purpose" IS '用途';

COMMENT ON COLUMN "als"."als_fault_consumable_t"."quantity" IS '数量';

COMMENT ON COLUMN "als"."als_fault_consumable_t"."remarks" IS '备注';

COMMENT ON COLUMN "als"."als_fault_consumable_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_fault_consumable_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_fault_consumable_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_fault_consumable_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_fault_diagnosis_result_t"
(
    "id" BIGINT NOT NULL,
    "diagnosis_id" BIGINT,
    "sortie_no" VARCHAR2(255),
    "aircraft_id" CHAR(255),
    "status" CHAR(1) DEFAULT 1,
    "tenant_id" BIGINT,
    "version" INTEGER,
    "del_flag" BIT DEFAULT 0,
    "create_by" BIGINT,
    "create_time" TIMESTAMP(6),
    "update_by" BIGINT,
    "update_time" TIMESTAMP(6),
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_fault_diagnosis_result_t" IS '故障诊断结果';

COMMENT ON COLUMN "als"."als_fault_diagnosis_result_t"."aircraft_id" IS '机号';

COMMENT ON COLUMN "als"."als_fault_diagnosis_result_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_fault_diagnosis_result_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_fault_diagnosis_result_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_fault_diagnosis_result_t"."diagnosis_id" IS '故障诊断编号';

COMMENT ON COLUMN "als"."als_fault_diagnosis_result_t"."id" IS '编号';

COMMENT ON COLUMN "als"."als_fault_diagnosis_result_t"."sortie_no" IS '架次号';

COMMENT ON COLUMN "als"."als_fault_diagnosis_result_t"."status" IS '状态（1正常）';

COMMENT ON COLUMN "als"."als_fault_diagnosis_result_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_fault_diagnosis_result_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_fault_diagnosis_result_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_fault_diagnosis_result_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_fault_diagnosis_t"
(
    "id" BIGINT NOT NULL,
    "sortie_no" VARCHAR2(255),
    "aircraft_id" CHAR(255),
    "model_type" CHAR(1),
    "param" VARCHAR2(2000),
    "column_data" VARCHAR2(2000),
    "oss_id" BIGINT,
    "result_content" VARCHAR2(4000),
    "status" CHAR(1) DEFAULT 1,
    "tenant_id" BIGINT,
    "version" INTEGER,
    "del_flag" BIT DEFAULT 0,
    "create_by" BIGINT,
    "create_time" TIMESTAMP(6),
    "update_by" BIGINT,
    "update_time" TIMESTAMP(6),
    "model_type_1" CHAR(1),
    "param_1" VARCHAR2(4000),
    "column_data_1" VARCHAR2(4000),
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_fault_diagnosis_t" IS '故障诊断';

COMMENT ON COLUMN "als"."als_fault_diagnosis_t"."aircraft_id" IS '机号';

COMMENT ON COLUMN "als"."als_fault_diagnosis_t"."column_data" IS '数据列';

COMMENT ON COLUMN "als"."als_fault_diagnosis_t"."column_data_1" IS '数据列';

COMMENT ON COLUMN "als"."als_fault_diagnosis_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_fault_diagnosis_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_fault_diagnosis_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_fault_diagnosis_t"."id" IS '编号';

COMMENT ON COLUMN "als"."als_fault_diagnosis_t"."model_type" IS '模型类型';

COMMENT ON COLUMN "als"."als_fault_diagnosis_t"."model_type_1" IS '模型类型';

COMMENT ON COLUMN "als"."als_fault_diagnosis_t"."oss_id" IS '文件Id';

COMMENT ON COLUMN "als"."als_fault_diagnosis_t"."param" IS '参数';

COMMENT ON COLUMN "als"."als_fault_diagnosis_t"."param_1" IS '参数';

COMMENT ON COLUMN "als"."als_fault_diagnosis_t"."result_content" IS '结果';

COMMENT ON COLUMN "als"."als_fault_diagnosis_t"."sortie_no" IS '架次号';

COMMENT ON COLUMN "als"."als_fault_diagnosis_t"."status" IS '状态（1正常）';

COMMENT ON COLUMN "als"."als_fault_diagnosis_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_fault_diagnosis_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_fault_diagnosis_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_fault_diagnosis_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_fault_equipment_t"
(
    "id" BIGINT NOT NULL,
    "equipment_code" VARCHAR2(255),
    "equipment_name" VARCHAR2(255),
    "model_number" VARCHAR2(255),
    "quantity" INTEGER,
    "purpose" VARCHAR2(255),
    "remarks" VARCHAR2(900),
    "tenant_id" BIGINT,
    "version" INTEGER,
    "del_flag" BIT DEFAULT 0,
    "create_by" BIGINT,
    "create_time" TIMESTAMP(6),
    "update_by" BIGINT,
    "update_time" TIMESTAMP(6),
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_fault_equipment_t" IS '故障所需设备';

COMMENT ON COLUMN "als"."als_fault_equipment_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_fault_equipment_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_fault_equipment_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_fault_equipment_t"."equipment_code" IS '设备编号';

COMMENT ON COLUMN "als"."als_fault_equipment_t"."equipment_name" IS '设备名称';

COMMENT ON COLUMN "als"."als_fault_equipment_t"."id" IS '编号';

COMMENT ON COLUMN "als"."als_fault_equipment_t"."model_number" IS '规格型号';

COMMENT ON COLUMN "als"."als_fault_equipment_t"."purpose" IS '用途';

COMMENT ON COLUMN "als"."als_fault_equipment_t"."quantity" IS '数量';

COMMENT ON COLUMN "als"."als_fault_equipment_t"."remarks" IS '备注';

COMMENT ON COLUMN "als"."als_fault_equipment_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_fault_equipment_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_fault_equipment_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_fault_equipment_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_fault_notes_t"
(
    "id" BIGINT NOT NULL,
    "note_content" VARCHAR2(900),
    "IMAGE" VARCHAR2(255),
    "remarks" VARCHAR2(900),
    "tenant_id" BIGINT,
    "version" INTEGER,
    "del_flag" BIT DEFAULT 0,
    "create_by" BIGINT,
    "create_time" TIMESTAMP(6),
    "update_by" BIGINT,
    "update_time" TIMESTAMP(6),
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_fault_notes_t" IS '故障注意事项';

COMMENT ON COLUMN "als"."als_fault_notes_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_fault_notes_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_fault_notes_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_fault_notes_t"."id" IS '编号';

COMMENT ON COLUMN "als"."als_fault_notes_t"."IMAGE" IS '图片';

COMMENT ON COLUMN "als"."als_fault_notes_t"."note_content" IS '注意内容';

COMMENT ON COLUMN "als"."als_fault_notes_t"."remarks" IS '备注';

COMMENT ON COLUMN "als"."als_fault_notes_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_fault_notes_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_fault_notes_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_fault_notes_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_fault_personnel_t"
(
    "id" BIGINT NOT NULL,
    "personnel" VARCHAR2(255),
    "position" VARCHAR2(900),
    "quantity" INTEGER,
    "duties" VARCHAR2(255),
    "remarks" VARCHAR2(900),
    "tenant_id" BIGINT,
    "version" INTEGER,
    "del_flag" BIT DEFAULT 0,
    "create_by" BIGINT,
    "create_time" TIMESTAMP(6),
    "update_by" BIGINT,
    "update_time" TIMESTAMP(6),
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_fault_personnel_t" IS '故障操作人员';

COMMENT ON COLUMN "als"."als_fault_personnel_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_fault_personnel_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_fault_personnel_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_fault_personnel_t"."duties" IS '职责';

COMMENT ON COLUMN "als"."als_fault_personnel_t"."id" IS '编号';

COMMENT ON COLUMN "als"."als_fault_personnel_t"."personnel" IS '人员';

COMMENT ON COLUMN "als"."als_fault_personnel_t"."position" IS '岗位';

COMMENT ON COLUMN "als"."als_fault_personnel_t"."quantity" IS '数量';

COMMENT ON COLUMN "als"."als_fault_personnel_t"."remarks" IS '备注';

COMMENT ON COLUMN "als"."als_fault_personnel_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_fault_personnel_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_fault_personnel_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_fault_personnel_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_fault_setps_t"
(
    "id" BIGINT NOT NULL,
    "setps" INTEGER,
    "method" VARCHAR2(1500),
    "IMAGE" VARCHAR2(255),
    "remarks" VARCHAR2(900),
    "tenant_id" BIGINT,
    "version" INTEGER,
    "del_flag" BIT DEFAULT 0,
    "create_by" BIGINT,
    "create_time" TIMESTAMP(6),
    "update_by" BIGINT,
    "update_time" TIMESTAMP(6),
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_fault_setps_t" IS '故障操作步骤';

COMMENT ON COLUMN "als"."als_fault_setps_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_fault_setps_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_fault_setps_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_fault_setps_t"."id" IS '编号';

COMMENT ON COLUMN "als"."als_fault_setps_t"."IMAGE" IS '图片';

COMMENT ON COLUMN "als"."als_fault_setps_t"."method" IS '操作方法';

COMMENT ON COLUMN "als"."als_fault_setps_t"."remarks" IS '备注';

COMMENT ON COLUMN "als"."als_fault_setps_t"."setps" IS '操作步骤';

COMMENT ON COLUMN "als"."als_fault_setps_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_fault_setps_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_fault_setps_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_fault_setps_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_fault_spare_parts_t"
(
    "id" BIGINT NOT NULL,
    "spare_parts_code" VARCHAR2(255),
    "spare_parts_name" VARCHAR2(255),
    "model_number" VARCHAR2(255),
    "quantity" INTEGER,
    "purpose" VARCHAR2(255),
    "remarks" VARCHAR2(900),
    "tenant_id" BIGINT,
    "version" INTEGER,
    "del_flag" BIT DEFAULT 0,
    "create_by" BIGINT,
    "create_time" TIMESTAMP(6),
    "update_by" BIGINT,
    "update_time" TIMESTAMP(6),
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_fault_spare_parts_t" IS '故障所需备件';

COMMENT ON COLUMN "als"."als_fault_spare_parts_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_fault_spare_parts_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_fault_spare_parts_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_fault_spare_parts_t"."id" IS '编号';

COMMENT ON COLUMN "als"."als_fault_spare_parts_t"."model_number" IS '规格型号';

COMMENT ON COLUMN "als"."als_fault_spare_parts_t"."purpose" IS '用途';

COMMENT ON COLUMN "als"."als_fault_spare_parts_t"."quantity" IS '数量';

COMMENT ON COLUMN "als"."als_fault_spare_parts_t"."remarks" IS '备注';

COMMENT ON COLUMN "als"."als_fault_spare_parts_t"."spare_parts_code" IS '备件编号';

COMMENT ON COLUMN "als"."als_fault_spare_parts_t"."spare_parts_name" IS '备件名称';

COMMENT ON COLUMN "als"."als_fault_spare_parts_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_fault_spare_parts_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_fault_spare_parts_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_fault_spare_parts_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_flight_split_task_t"
(
    "id" BIGINT NOT NULL,
    "flight_id" BIGINT,
    "aircraft_model" VARCHAR2(255),
    "aircraft_group" VARCHAR2(255),
    "duration" VARCHAR2(255),
    "DEVICE" VARCHAR2(255),
    "device_count" INTEGER,
    "unit" VARCHAR2(255),
    "remark" VARCHAR2(900),
    "status" CHAR(1) DEFAULT 1,
    "tenant_id" BIGINT,
    "version" INTEGER,
    "del_flag" BIT DEFAULT 0,
    "create_by" BIGINT,
    "create_time" TIMESTAMP(6),
    "update_by" BIGINT,
    "update_time" TIMESTAMP(6),
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_flight_split_task_t" IS '飞行分解任务';

COMMENT ON COLUMN "als"."als_flight_split_task_t"."aircraft_group" IS '机组';

COMMENT ON COLUMN "als"."als_flight_split_task_t"."aircraft_model" IS '机型';

COMMENT ON COLUMN "als"."als_flight_split_task_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_flight_split_task_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_flight_split_task_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_flight_split_task_t"."DEVICE" IS '设备';

COMMENT ON COLUMN "als"."als_flight_split_task_t"."device_count" IS '数量';

COMMENT ON COLUMN "als"."als_flight_split_task_t"."duration" IS '时长';

COMMENT ON COLUMN "als"."als_flight_split_task_t"."flight_id" IS '飞行编号';

COMMENT ON COLUMN "als"."als_flight_split_task_t"."id" IS '编号';

COMMENT ON COLUMN "als"."als_flight_split_task_t"."remark" IS '备注';

COMMENT ON COLUMN "als"."als_flight_split_task_t"."status" IS '状态（1正常）';

COMMENT ON COLUMN "als"."als_flight_split_task_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_flight_split_task_t"."unit" IS '单位';

COMMENT ON COLUMN "als"."als_flight_split_task_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_flight_split_task_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_flight_split_task_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_flight_task_t"
(
    "id" BIGINT NOT NULL,
    "sortie_no" BIGINT,
    "aircraft_model" VARCHAR2(255),
    "aircraft_id" CHAR(255),
    "start_time" TIMESTAMP(6),
    "end_time" VARCHAR2(255),
    "train_exercise" VARCHAR2(255),
    "status" CHAR(1) DEFAULT 1,
    "tenant_id" BIGINT,
    "version" INTEGER,
    "del_flag" BIT DEFAULT 0,
    "create_by" BIGINT,
    "create_time" TIMESTAMP(6),
    "update_by" BIGINT,
    "update_time" TIMESTAMP(6),
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_flight_task_t" IS '飞行任务';

COMMENT ON COLUMN "als"."als_flight_task_t"."aircraft_id" IS '机号';

COMMENT ON COLUMN "als"."als_flight_task_t"."aircraft_model" IS '机型';

COMMENT ON COLUMN "als"."als_flight_task_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_flight_task_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_flight_task_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_flight_task_t"."end_time" IS '降落时间';

COMMENT ON COLUMN "als"."als_flight_task_t"."id" IS '编号';

COMMENT ON COLUMN "als"."als_flight_task_t"."sortie_no" IS '架次号';

COMMENT ON COLUMN "als"."als_flight_task_t"."start_time" IS '起飞时间';

COMMENT ON COLUMN "als"."als_flight_task_t"."status" IS '状态（1正常）';

COMMENT ON COLUMN "als"."als_flight_task_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_flight_task_t"."train_exercise" IS '飞行课目';

COMMENT ON COLUMN "als"."als_flight_task_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_flight_task_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_flight_task_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_life_prediction_result_t"
(
    "id" BIGINT NOT NULL,
    "life_id" BIGINT,
    "aircraft_id" CHAR(255),
    "name" VARCHAR2(255),
    "model" VARCHAR2(255),
    "SYSTEM" VARCHAR2(255),
    "method_type" CHAR(1),
    "remain_tiem" VARCHAR2(255),
    "status" CHAR(1) DEFAULT 1,
    "tenant_id" BIGINT,
    "version" INTEGER,
    "del_flag" BIT DEFAULT 0,
    "create_by" BIGINT,
    "create_time" TIMESTAMP(6),
    "update_by" BIGINT,
    "update_time" TIMESTAMP(6),
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_life_prediction_result_t" IS '寿命预测结果';

COMMENT ON COLUMN "als"."als_life_prediction_result_t"."aircraft_id" IS '机号';

COMMENT ON COLUMN "als"."als_life_prediction_result_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_life_prediction_result_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_life_prediction_result_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_life_prediction_result_t"."id" IS '编号';

COMMENT ON COLUMN "als"."als_life_prediction_result_t"."life_id" IS '寿命预测编号';

COMMENT ON COLUMN "als"."als_life_prediction_result_t"."method_type" IS '处理方式';

COMMENT ON COLUMN "als"."als_life_prediction_result_t"."model" IS '型号';

COMMENT ON COLUMN "als"."als_life_prediction_result_t"."name" IS '部件名称';

COMMENT ON COLUMN "als"."als_life_prediction_result_t"."remain_tiem" IS '剩余时长（h）';

COMMENT ON COLUMN "als"."als_life_prediction_result_t"."status" IS '状态（1正常）';

COMMENT ON COLUMN "als"."als_life_prediction_result_t"."SYSTEM" IS '所属系统';

COMMENT ON COLUMN "als"."als_life_prediction_result_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_life_prediction_result_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_life_prediction_result_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_life_prediction_result_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_life_prediction_t"
(
    "id" BIGINT NOT NULL,
    "aircraft_id" CHAR(255),
    "name" VARCHAR2(255),
    "model" VARCHAR2(255),
    "SYSTEM" VARCHAR2(255),
    "method_type" CHAR(1),
    "remain_tiem" VARCHAR2(255),
    "status" CHAR(1) DEFAULT 1,
    "tenant_id" BIGINT,
    "version" INTEGER,
    "del_flag" BIT DEFAULT 0,
    "create_by" BIGINT,
    "create_time" TIMESTAMP(6),
    "update_by" BIGINT,
    "update_time" TIMESTAMP(6),
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_life_prediction_t" IS '寿命预测';

COMMENT ON COLUMN "als"."als_life_prediction_t"."aircraft_id" IS '机号';

COMMENT ON COLUMN "als"."als_life_prediction_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_life_prediction_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_life_prediction_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_life_prediction_t"."id" IS '编号';

COMMENT ON COLUMN "als"."als_life_prediction_t"."method_type" IS '处理方式';

COMMENT ON COLUMN "als"."als_life_prediction_t"."model" IS '型号';

COMMENT ON COLUMN "als"."als_life_prediction_t"."name" IS '部件名称';

COMMENT ON COLUMN "als"."als_life_prediction_t"."remain_tiem" IS '剩余时长（h）';

COMMENT ON COLUMN "als"."als_life_prediction_t"."status" IS '状态（1正常）';

COMMENT ON COLUMN "als"."als_life_prediction_t"."SYSTEM" IS '所属系统';

COMMENT ON COLUMN "als"."als_life_prediction_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_life_prediction_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_life_prediction_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_life_prediction_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_maintenance_decision_t"
(
    "id" BIGINT NOT NULL,
    "sortie_no" VARCHAR2(255),
    "aircraft_id" VARCHAR2(255),
    "result_id" BIGINT,
    "code" VARCHAR2(255),
    "system_name" VARCHAR2(255),
    "unit_name" VARCHAR2(255),
    "fault_part" VARCHAR2(255),
    "proposal" VARCHAR2(3000),
    "status" CHAR(1) DEFAULT 1,
    "tenant_id" BIGINT,
    "version" INTEGER,
    "del_flag" BIT DEFAULT 0,
    "create_by" BIGINT,
    "create_time" DATE,
    "update_by" BIGINT,
    "update_time" DATE,
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_maintenance_decision_t" IS '辅助维修决策';

COMMENT ON COLUMN "als"."als_maintenance_decision_t"."aircraft_id" IS '机号';

COMMENT ON COLUMN "als"."als_maintenance_decision_t"."code" IS '故障代码';

COMMENT ON COLUMN "als"."als_maintenance_decision_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_maintenance_decision_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_maintenance_decision_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_maintenance_decision_t"."fault_part" IS '故障部件';

COMMENT ON COLUMN "als"."als_maintenance_decision_t"."id" IS '编号';

COMMENT ON COLUMN "als"."als_maintenance_decision_t"."proposal" IS '维修建议';

COMMENT ON COLUMN "als"."als_maintenance_decision_t"."result_id" IS '诊断结果';

COMMENT ON COLUMN "als"."als_maintenance_decision_t"."sortie_no" IS '架次号';

COMMENT ON COLUMN "als"."als_maintenance_decision_t"."status" IS '状态（1正常）';

COMMENT ON COLUMN "als"."als_maintenance_decision_t"."system_name" IS '系统';

COMMENT ON COLUMN "als"."als_maintenance_decision_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_maintenance_decision_t"."unit_name" IS '单位';

COMMENT ON COLUMN "als"."als_maintenance_decision_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_maintenance_decision_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_maintenance_decision_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_maintenance_task_t"
(
    "id" BIGINT NOT NULL,
    "task_id" BIGINT,
    "aircraft_code" VARCHAR2(255),
    "aircraft_type" VARCHAR2(255),
    "data_type" VARCHAR2(255),
    "fault_code" VARCHAR2(255),
    "fault_name" VARCHAR2(255),
    "LOCATION" VARCHAR2(255),
    "LEVEL" VARCHAR2(255),
    "fault_date" DATE,
    "fault_description" VARCHAR2(900),
    "symptoms" VARCHAR2(900),
    "fault_cause" VARCHAR2(900),
    "status" VARCHAR2(255),
    "remarks" VARCHAR2(900),
    "tenant_id" BIGINT,
    "version" INTEGER,
    "del_flag" BIT DEFAULT 0,
    "create_by" BIGINT,
    "create_time" TIMESTAMP(6),
    "update_by" BIGINT,
    "update_time" TIMESTAMP(6),
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_maintenance_task_t" IS '维修信息';

COMMENT ON COLUMN "als"."als_maintenance_task_t"."aircraft_code" IS '飞机编码';

COMMENT ON COLUMN "als"."als_maintenance_task_t"."aircraft_type" IS '飞机机型';

COMMENT ON COLUMN "als"."als_maintenance_task_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_maintenance_task_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_maintenance_task_t"."data_type" IS '数据来源';

COMMENT ON COLUMN "als"."als_maintenance_task_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_maintenance_task_t"."fault_cause" IS '故障原因';

COMMENT ON COLUMN "als"."als_maintenance_task_t"."fault_code" IS '故障代码';

COMMENT ON COLUMN "als"."als_maintenance_task_t"."fault_date" IS '故障发生时间';

COMMENT ON COLUMN "als"."als_maintenance_task_t"."fault_description" IS '故障描述';

COMMENT ON COLUMN "als"."als_maintenance_task_t"."fault_name" IS '故障名称';

COMMENT ON COLUMN "als"."als_maintenance_task_t"."id" IS '编号';

COMMENT ON COLUMN "als"."als_maintenance_task_t"."LEVEL" IS '故障等级';

COMMENT ON COLUMN "als"."als_maintenance_task_t"."LOCATION" IS '故障位置';

COMMENT ON COLUMN "als"."als_maintenance_task_t"."remarks" IS '备注';

COMMENT ON COLUMN "als"."als_maintenance_task_t"."status" IS '任务状态';

COMMENT ON COLUMN "als"."als_maintenance_task_t"."symptoms" IS '故障现象';

COMMENT ON COLUMN "als"."als_maintenance_task_t"."task_id" IS '来源ID';

COMMENT ON COLUMN "als"."als_maintenance_task_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_maintenance_task_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_maintenance_task_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_maintenance_task_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_model_t"
(
    "id" BIGINT NOT NULL,
    "name" VARCHAR2(255),
    "TYPE" CHAR(1),
    "url" VARCHAR2(255),
    "param" VARCHAR2(4000),
    "column_data" VARCHAR2(4000),
    "status" CHAR(1) DEFAULT 1,
    "remark" VARCHAR2(900),
    "tenant_id" BIGINT,
    "version" INTEGER,
    "del_flag" BIT DEFAULT 0,
    "create_by" BIGINT,
    "create_time" TIMESTAMP(6),
    "update_by" BIGINT,
    "update_time" TIMESTAMP(6),
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_model_t" IS '模型信息';

COMMENT ON COLUMN "als"."als_model_t"."column_data" IS '数据列';

COMMENT ON COLUMN "als"."als_model_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_model_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_model_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_model_t"."id" IS '编号';

COMMENT ON COLUMN "als"."als_model_t"."name" IS '模型名称';

COMMENT ON COLUMN "als"."als_model_t"."param" IS '参数';

COMMENT ON COLUMN "als"."als_model_t"."remark" IS '备注';

COMMENT ON COLUMN "als"."als_model_t"."status" IS '状态（1正常）';

COMMENT ON COLUMN "als"."als_model_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_model_t"."TYPE" IS '模型类型';

COMMENT ON COLUMN "als"."als_model_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_model_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_model_t"."url" IS '模型链接';

COMMENT ON COLUMN "als"."als_model_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_part_replacement_t"
(
    "id" BIGINT NOT NULL,
    "aircraft_type" VARCHAR2(255),
    "aircraft_code" VARCHAR2(255),
    "before_equipment_code" VARCHAR2(255),
    "before_equipment_name" VARCHAR2(255),
    "before_model_number" VARCHAR2(255),
    "after_equipment_code" VARCHAR2(255),
    "after_equipment_name" VARCHAR2(255),
    "after_model_number" VARCHAR2(255),
    "quantity" VARCHAR2(255),
    "remarks" VARCHAR2(900),
    "tenant_id" BIGINT,
    "version" INTEGER,
    "del_flag" BIT DEFAULT 0,
    "create_by" BIGINT,
    "create_time" TIMESTAMP(6),
    "update_by" BIGINT,
    "update_time" TIMESTAMP(6),
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_part_replacement_t" IS '换件记录';

COMMENT ON COLUMN "als"."als_part_replacement_t"."after_equipment_code" IS '换件后器材编码';

COMMENT ON COLUMN "als"."als_part_replacement_t"."after_equipment_name" IS '换件后器材名称';

COMMENT ON COLUMN "als"."als_part_replacement_t"."after_model_number" IS '换件后规格型号';

COMMENT ON COLUMN "als"."als_part_replacement_t"."aircraft_code" IS '飞机编码';

COMMENT ON COLUMN "als"."als_part_replacement_t"."aircraft_type" IS '飞机机型';

COMMENT ON COLUMN "als"."als_part_replacement_t"."before_equipment_code" IS '换件前器材编码';

COMMENT ON COLUMN "als"."als_part_replacement_t"."before_equipment_name" IS '换件前器材名称';

COMMENT ON COLUMN "als"."als_part_replacement_t"."before_model_number" IS '换件前规格型号';

COMMENT ON COLUMN "als"."als_part_replacement_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_part_replacement_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_part_replacement_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_part_replacement_t"."id" IS '编号';

COMMENT ON COLUMN "als"."als_part_replacement_t"."quantity" IS '更换数量';

COMMENT ON COLUMN "als"."als_part_replacement_t"."remarks" IS '备注';

COMMENT ON COLUMN "als"."als_part_replacement_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_part_replacement_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_part_replacement_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_part_replacement_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_personnel_allocation_t"
(
    "id" BIGINT NOT NULL,
    "task_id" BIGINT,
    "personnel" VARCHAR2(255),
    "position" VARCHAR2(900),
    "quantity" INTEGER,
    "duties" VARCHAR2(255),
    "remarks" VARCHAR2(900),
    "tenant_id" BIGINT,
    "version" INTEGER,
    "del_flag" BIT DEFAULT 0,
    "create_by" BIGINT,
    "create_time" TIMESTAMP(6),
    "update_by" BIGINT,
    "update_time" TIMESTAMP(6),
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_personnel_allocation_t" IS '维修任务任务派遣';

COMMENT ON COLUMN "als"."als_personnel_allocation_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_personnel_allocation_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_personnel_allocation_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_personnel_allocation_t"."duties" IS '职责';

COMMENT ON COLUMN "als"."als_personnel_allocation_t"."id" IS '编号';

COMMENT ON COLUMN "als"."als_personnel_allocation_t"."personnel" IS '人员';

COMMENT ON COLUMN "als"."als_personnel_allocation_t"."position" IS '岗位';

COMMENT ON COLUMN "als"."als_personnel_allocation_t"."quantity" IS '数量';

COMMENT ON COLUMN "als"."als_personnel_allocation_t"."remarks" IS '备注';

COMMENT ON COLUMN "als"."als_personnel_allocation_t"."task_id" IS '任务Id';

COMMENT ON COLUMN "als"."als_personnel_allocation_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_personnel_allocation_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_personnel_allocation_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_personnel_allocation_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_pre_processing_t"
(
    "id" BIGINT NOT NULL,
    "sortie_no" VARCHAR2(255),
    "aircraft_id" CHAR(255),
    "model_type" CHAR(1),
    "param" VARCHAR2(2000),
    "column_data" VARCHAR2(2000),
    "oss_id" BIGINT,
    "RESULT" BIGINT,
    "status" CHAR(1) DEFAULT 1,
    "tenant_id" BIGINT,
    "version" INTEGER,
    "del_flag" BIT DEFAULT 0,
    "create_by" BIGINT,
    "create_time" TIMESTAMP(6),
    "update_by" BIGINT,
    "update_time" TIMESTAMP(6),
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_pre_processing_t" IS '预处理';

COMMENT ON COLUMN "als"."als_pre_processing_t"."aircraft_id" IS '机号';

COMMENT ON COLUMN "als"."als_pre_processing_t"."column_data" IS '数据列';

COMMENT ON COLUMN "als"."als_pre_processing_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_pre_processing_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_pre_processing_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_pre_processing_t"."id" IS '编号';

COMMENT ON COLUMN "als"."als_pre_processing_t"."model_type" IS '模型类型';

COMMENT ON COLUMN "als"."als_pre_processing_t"."oss_id" IS '文件Id';

COMMENT ON COLUMN "als"."als_pre_processing_t"."param" IS '参数';

COMMENT ON COLUMN "als"."als_pre_processing_t"."RESULT" IS '结果';

COMMENT ON COLUMN "als"."als_pre_processing_t"."sortie_no" IS '架次号';

COMMENT ON COLUMN "als"."als_pre_processing_t"."status" IS '状态（1正常）';

COMMENT ON COLUMN "als"."als_pre_processing_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_pre_processing_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_pre_processing_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_pre_processing_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_product_t"
(
    "id" BIGINT NOT NULL,
    "parent_name" VARCHAR2(255),
    "parent_id" BIGINT,
    "sns_code" VARCHAR2(255),
    "name" VARCHAR2(255),
    "ancestors" VARCHAR2(800),
    "order_num" INTEGER DEFAULT 0,
    "tenant_id" BIGINT,
    "version" INTEGER,
    "del_flag" BIT DEFAULT 0,
    "create_by" BIGINT,
    "create_time" TIMESTAMP(6),
    "update_by" BIGINT,
    "update_time" TIMESTAMP(6),
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_product_t" IS '产品树';

COMMENT ON COLUMN "als"."als_product_t"."ancestors" IS '祖级列表';

COMMENT ON COLUMN "als"."als_product_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_product_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_product_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_product_t"."id" IS '编号';

COMMENT ON COLUMN "als"."als_product_t"."name" IS '产品名称';

COMMENT ON COLUMN "als"."als_product_t"."order_num" IS '显示顺序';

COMMENT ON COLUMN "als"."als_product_t"."parent_id" IS '父id';

COMMENT ON COLUMN "als"."als_product_t"."parent_name" IS '归属';

COMMENT ON COLUMN "als"."als_product_t"."sns_code" IS 'SNS编号';

COMMENT ON COLUMN "als"."als_product_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_product_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_product_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_product_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_resource_allocation_t"
(
    "id" BIGINT NOT NULL,
    "task_id" BIGINT,
    "device_code" VARCHAR2(255),
    "device_name" VARCHAR2(255),
    "TYPE" VARCHAR2(255),
    "model_number" VARCHAR2(255),
    "quantity" INTEGER,
    "purpose" VARCHAR2(255),
    "remarks" VARCHAR2(900),
    "tenant_id" BIGINT,
    "version" INTEGER,
    "del_flag" BIT DEFAULT 0,
    "create_by" BIGINT,
    "create_time" TIMESTAMP(6),
    "update_by" BIGINT,
    "update_time" TIMESTAMP(6),
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_resource_allocation_t" IS '维修任务资源分配';

COMMENT ON COLUMN "als"."als_resource_allocation_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_resource_allocation_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_resource_allocation_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_resource_allocation_t"."device_code" IS '设备编号';

COMMENT ON COLUMN "als"."als_resource_allocation_t"."device_name" IS '设备名称';

COMMENT ON COLUMN "als"."als_resource_allocation_t"."id" IS '编号';

COMMENT ON COLUMN "als"."als_resource_allocation_t"."model_number" IS '规格型号';

COMMENT ON COLUMN "als"."als_resource_allocation_t"."purpose" IS '用途';

COMMENT ON COLUMN "als"."als_resource_allocation_t"."quantity" IS '数量';

COMMENT ON COLUMN "als"."als_resource_allocation_t"."remarks" IS '备注';

COMMENT ON COLUMN "als"."als_resource_allocation_t"."task_id" IS '任务Id';

COMMENT ON COLUMN "als"."als_resource_allocation_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_resource_allocation_t"."TYPE" IS '类型';

COMMENT ON COLUMN "als"."als_resource_allocation_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_resource_allocation_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_resource_allocation_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_safe_rule_sub_t"
(
    "id" BIGINT NOT NULL,
    "aircraft_model" VARCHAR2(255),
    "aircraft_group" VARCHAR2(255),
    "duration" VARCHAR2(255),
    "DEVICE" VARCHAR2(255),
    "device_count" INTEGER,
    "unit" VARCHAR2(255),
    "remark" VARCHAR2(900),
    "status" CHAR(1) DEFAULT 1,
    "tenant_id" BIGINT,
    "version" INTEGER,
    "del_flag" BIT DEFAULT 0,
    "create_by" BIGINT,
    "create_time" TIMESTAMP(6),
    "update_by" BIGINT,
    "update_time" TIMESTAMP(6),
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_safe_rule_sub_t" IS '保障规则子表';

COMMENT ON COLUMN "als"."als_safe_rule_sub_t"."aircraft_group" IS '机组';

COMMENT ON COLUMN "als"."als_safe_rule_sub_t"."aircraft_model" IS '机型';

COMMENT ON COLUMN "als"."als_safe_rule_sub_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_safe_rule_sub_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_safe_rule_sub_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_safe_rule_sub_t"."DEVICE" IS '设备';

COMMENT ON COLUMN "als"."als_safe_rule_sub_t"."device_count" IS '数量';

COMMENT ON COLUMN "als"."als_safe_rule_sub_t"."duration" IS '时长';

COMMENT ON COLUMN "als"."als_safe_rule_sub_t"."id" IS '编号';

COMMENT ON COLUMN "als"."als_safe_rule_sub_t"."remark" IS '备注';

COMMENT ON COLUMN "als"."als_safe_rule_sub_t"."status" IS '状态（1正常）';

COMMENT ON COLUMN "als"."als_safe_rule_sub_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_safe_rule_sub_t"."unit" IS '单位';

COMMENT ON COLUMN "als"."als_safe_rule_sub_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_safe_rule_sub_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_safe_rule_sub_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_safe_rule_t"
(
    "id" BIGINT NOT NULL,
    "aircraft_model" VARCHAR2(255),
    "duration" VARCHAR2(255),
    "train_exercise" VARCHAR2(255),
    "status" CHAR(1) DEFAULT 1,
    "tenant_id" BIGINT,
    "version" INTEGER,
    "del_flag" BIT DEFAULT 0,
    "create_by" BIGINT,
    "create_time" TIMESTAMP(6),
    "update_by" BIGINT,
    "update_time" TIMESTAMP(6),
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_safe_rule_t" IS '保障规则';

COMMENT ON COLUMN "als"."als_safe_rule_t"."aircraft_model" IS '机型';

COMMENT ON COLUMN "als"."als_safe_rule_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_safe_rule_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_safe_rule_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_safe_rule_t"."duration" IS '时长';

COMMENT ON COLUMN "als"."als_safe_rule_t"."id" IS '编号';

COMMENT ON COLUMN "als"."als_safe_rule_t"."status" IS '状态（1正常）';

COMMENT ON COLUMN "als"."als_safe_rule_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_safe_rule_t"."train_exercise" IS '飞行课目';

COMMENT ON COLUMN "als"."als_safe_rule_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_safe_rule_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_safe_rule_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_sm_task_t"
(
    "id" BIGINT NOT NULL,
    "aircraft_id" VARCHAR2(255),
    "aircraft_model" VARCHAR2(255),
    "name" VARCHAR2(255),
    "specialty" VARCHAR2(255),
    "task_code" VARCHAR2(255),
    "period_time" VARCHAR2(255),
    "remain_time" VARCHAR2(255) DEFAULT 1,
    "head_name" VARCHAR2(255),
    "system_name" VARCHAR2(255),
    "contents" VARCHAR2(255),
    "remark" VARCHAR2(900),
    "tenant_id" BIGINT,
    "version" INTEGER,
    "del_flag" BIT DEFAULT 0,
    "create_by" BIGINT,
    "create_time" DATE,
    "update_by" BIGINT,
    "update_time" DATE,
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_sm_task_t" IS '定检任务';

COMMENT ON COLUMN "als"."als_sm_task_t"."aircraft_id" IS '机号';

COMMENT ON COLUMN "als"."als_sm_task_t"."aircraft_model" IS '机型';

COMMENT ON COLUMN "als"."als_sm_task_t"."contents" IS '任务内容';

COMMENT ON COLUMN "als"."als_sm_task_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_sm_task_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_sm_task_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_sm_task_t"."head_name" IS '负责人';

COMMENT ON COLUMN "als"."als_sm_task_t"."id" IS '编号';

COMMENT ON COLUMN "als"."als_sm_task_t"."name" IS '任务名称';

COMMENT ON COLUMN "als"."als_sm_task_t"."period_time" IS '周期';

COMMENT ON COLUMN "als"."als_sm_task_t"."remain_time" IS '剩余时间';

COMMENT ON COLUMN "als"."als_sm_task_t"."remark" IS '备注';

COMMENT ON COLUMN "als"."als_sm_task_t"."specialty" IS '专业';

COMMENT ON COLUMN "als"."als_sm_task_t"."system_name" IS '系统';

COMMENT ON COLUMN "als"."als_sm_task_t"."task_code" IS '任务编码';

COMMENT ON COLUMN "als"."als_sm_task_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_sm_task_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_sm_task_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_sm_task_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_sortie_t"
(
    "id" BIGINT NOT NULL,
    "sortie_no" VARCHAR2(255),
    "aircraft_id" BIGINT,
    "flight_date" DATE,
    "start_time" TIMESTAMP(6),
    "end_time" VARCHAR2(255),
    "duration" VARCHAR2(255),
    "tenant_id" BIGINT,
    "version" INTEGER,
    "del_flag" BIT DEFAULT 0,
    "create_by" BIGINT,
    "create_time" TIMESTAMP(6),
    "update_by" BIGINT,
    "update_time" TIMESTAMP(6),
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_sortie_t" IS '架次';

COMMENT ON COLUMN "als"."als_sortie_t"."aircraft_id" IS '机号';

COMMENT ON COLUMN "als"."als_sortie_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_sortie_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_sortie_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_sortie_t"."duration" IS '飞行时长';

COMMENT ON COLUMN "als"."als_sortie_t"."end_time" IS '结束时间';

COMMENT ON COLUMN "als"."als_sortie_t"."flight_date" IS '飞行日期';

COMMENT ON COLUMN "als"."als_sortie_t"."id" IS '编号';

COMMENT ON COLUMN "als"."als_sortie_t"."sortie_no" IS '架次号';

COMMENT ON COLUMN "als"."als_sortie_t"."start_time" IS '开始时间';

COMMENT ON COLUMN "als"."als_sortie_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_sortie_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_sortie_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_sortie_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_spare_parts_t"
(
    "id" BIGINT NOT NULL,
    "name" VARCHAR2(255),
    "model" VARCHAR2(255),
    "system_name" VARCHAR2(255),
    "factory" VARCHAR2(255),
    "quantity" INTEGER,
    "status" CHAR(1) DEFAULT 1,
    "tenant_id" BIGINT,
    "version" INTEGER,
    "del_flag" BIT DEFAULT 0,
    "create_by" BIGINT,
    "create_time" TIMESTAMP(6),
    "update_by" BIGINT,
    "update_time" TIMESTAMP(6),
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_spare_parts_t" IS '部件';

COMMENT ON COLUMN "als"."als_spare_parts_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_spare_parts_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_spare_parts_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_spare_parts_t"."factory" IS '制造厂';

COMMENT ON COLUMN "als"."als_spare_parts_t"."id" IS '编号';

COMMENT ON COLUMN "als"."als_spare_parts_t"."model" IS '型号';

COMMENT ON COLUMN "als"."als_spare_parts_t"."name" IS '部件名称';

COMMENT ON COLUMN "als"."als_spare_parts_t"."quantity" IS '数量';

COMMENT ON COLUMN "als"."als_spare_parts_t"."status" IS '状态（1正常）';

COMMENT ON COLUMN "als"."als_spare_parts_t"."system_name" IS '所属系统';

COMMENT ON COLUMN "als"."als_spare_parts_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_spare_parts_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_spare_parts_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_spare_parts_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_task_t"
(
    "id" BIGINT NOT NULL,
    "name" VARCHAR2(255),
    "source" CHAR(1),
    "sortie_no" BIGINT,
    "aircraft_id" CHAR(255),
    "data_id" BIGINT,
    "pre_id" BIGINT,
    "false_alarm_id" BIGINT,
    "fault_id" BIGINT,
    "decision_id" BIGINT,
    "status" CHAR(1) DEFAULT 1,
    "tenant_id" BIGINT,
    "version" INTEGER,
    "del_flag" BIT DEFAULT 0,
    "create_by" BIGINT,
    "create_time" TIMESTAMP(6),
    "update_by" BIGINT,
    "update_time" TIMESTAMP(6),
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_task_t" IS '任务信息';

COMMENT ON COLUMN "als"."als_task_t"."aircraft_id" IS '机号';

COMMENT ON COLUMN "als"."als_task_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_task_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_task_t"."data_id" IS '数据编号';

COMMENT ON COLUMN "als"."als_task_t"."decision_id" IS '决策编号';

COMMENT ON COLUMN "als"."als_task_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_task_t"."false_alarm_id" IS '虚警编号';

COMMENT ON COLUMN "als"."als_task_t"."fault_id" IS '故障诊断编号';

COMMENT ON COLUMN "als"."als_task_t"."id" IS '任务编号';

COMMENT ON COLUMN "als"."als_task_t"."name" IS '任务名称';

COMMENT ON COLUMN "als"."als_task_t"."pre_id" IS '预处理编号';

COMMENT ON COLUMN "als"."als_task_t"."sortie_no" IS '架次号';

COMMENT ON COLUMN "als"."als_task_t"."source" IS '数据源';

COMMENT ON COLUMN "als"."als_task_t"."status" IS '状态（1正常）';

COMMENT ON COLUMN "als"."als_task_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_task_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_task_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_task_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_technical_doc_t"
(
    "id" BIGINT NOT NULL,
    "name" VARCHAR2(255),
    "author" VARCHAR2(255),
    "publication_Date" DATE,
    "TYPE" VARCHAR2(255),
    "oss_id" BIGINT,
    "tenant_id" BIGINT,
    "version" INTEGER,
    "del_flag" BIT DEFAULT 0,
    "create_by" BIGINT,
    "create_time" TIMESTAMP(6),
    "update_by" BIGINT,
    "update_time" TIMESTAMP(6),
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_technical_doc_t" IS '技术资料';

COMMENT ON COLUMN "als"."als_technical_doc_t"."author" IS '作者';

COMMENT ON COLUMN "als"."als_technical_doc_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_technical_doc_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_technical_doc_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_technical_doc_t"."id" IS '编号';

COMMENT ON COLUMN "als"."als_technical_doc_t"."name" IS '名称';

COMMENT ON COLUMN "als"."als_technical_doc_t"."oss_id" IS '文件Id';

COMMENT ON COLUMN "als"."als_technical_doc_t"."publication_Date" IS '出版时间';

COMMENT ON COLUMN "als"."als_technical_doc_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_technical_doc_t"."TYPE" IS '资料类型';

COMMENT ON COLUMN "als"."als_technical_doc_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_technical_doc_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_technical_doc_t"."version" IS '乐观锁';

CREATE TABLE "als"."als_warning_t"
(
    "id" BIGINT NOT NULL,
    "sortie_no" VARCHAR2(255),
    "aircraft_id" VARCHAR2(50),
    "code" VARCHAR2(255),
    "name" VARCHAR2(255),
    "describe" VARCHAR2(900),
    "status" CHAR(1) DEFAULT 1,
    "tenant_id" BIGINT,
    "version" INTEGER,
    "del_flag" BIT DEFAULT 0,
    "create_by" BIGINT,
    "create_time" TIMESTAMP(6),
    "update_by" BIGINT,
    "update_time" TIMESTAMP(6),
    NOT CLUSTER PRIMARY KEY("id")) STORAGE(ON "MAIN", CLUSTERBTR);

COMMENT ON TABLE "als"."als_warning_t" IS '警告信息';

COMMENT ON COLUMN "als"."als_warning_t"."aircraft_id" IS '机号';

COMMENT ON COLUMN "als"."als_warning_t"."code" IS '警告代码';

COMMENT ON COLUMN "als"."als_warning_t"."create_by" IS '创建人';

COMMENT ON COLUMN "als"."als_warning_t"."create_time" IS '创建时间';

COMMENT ON COLUMN "als"."als_warning_t"."del_flag" IS '删除标识（1删除 0未删除）';

COMMENT ON COLUMN "als"."als_warning_t"."describe" IS '警告描述';

COMMENT ON COLUMN "als"."als_warning_t"."id" IS '编号';

COMMENT ON COLUMN "als"."als_warning_t"."name" IS '警告名称';

COMMENT ON COLUMN "als"."als_warning_t"."sortie_no" IS '架次号';

COMMENT ON COLUMN "als"."als_warning_t"."status" IS '状态（1正常）';

COMMENT ON COLUMN "als"."als_warning_t"."tenant_id" IS '租户号';

COMMENT ON COLUMN "als"."als_warning_t"."update_by" IS '更新人';

COMMENT ON COLUMN "als"."als_warning_t"."update_time" IS '更新时间';

COMMENT ON COLUMN "als"."als_warning_t"."version" IS '乐观锁';

